@@ -1,3 +1,4 @@
+#define STRICT_R_HEADERS
 #include <R.h>
 #include <Rinternals.h>
 
@@ -9,4 +10,4 @@ SEXP double_to_bytes(SEXP x);
 SEXP bytes_to_double(SEXP x);
 SEXP complex_to_bytes(SEXP x);
 SEXP bytes_to_complex(SEXP x);
-SEXP sizeof_types();
+SEXP sizeof_types(void);
